@@ -1,9 +1,9 @@
 package MyUtil;
 
 use base qw/Util::Any/;
-our %Utils =
-  (
+our $Utils =
+  {
    list => [['List::Util' => 'lu_']],
-  );
+  };
 
 1;
